==> dde-shell_1.99.32.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_az.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="az">
<context>
    <name>GroupNotify</name>
    <message>
        <location filename="../GroupNotify.qml" line="51"/>
        <source>Clear All</source>
        <translation>مسح الكل</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <location filename="../NotifyHeader.qml" line="42"/>
        <source>Notification Center</source>
        <translation>مركز الإشعارات</translation>
    </message>
    <message>
        <location filename="../NotifyHeader.qml" line="90"/>
        <source>Clear All</source>
        <translation>مسح الكل</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <location filename="../NotifySetting.qml" line="18"/>
        <source>Unpin</source>
        <translation>إلغاء تثبيت</translation>
    </message>
    <message>
        <location filename="../NotifySetting.qml" line="18"/>
        <source>Pin</source>
        <translation>تثبيت</translation>
    </message>
    <message>
        <location filename="../NotifySetting.qml" line="26"/>
        <source>Notification Setting</source>
        <translation>إعداد الإشعارات</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <location filename="../notifyitem.cpp" line="78"/>
        <source>Just now</source>
        <translation>الآن</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="80"/>
        <source>%1 minutes ago</source>
        <translation>%1 دقيقة مضت</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="84"/>
        <source>1 hour ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="86"/>
        <source>%1 hours ago</source>
        <translation>%1 ساعة مضت</translation>
    </message>
    <message>
        <location filename="../notifyitem.cpp" line="90"/>
        <source>Yesterday </source>
        <translation>أمس </translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.37.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_az.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="az">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>مسح الكل</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>مركز الإشعارات</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>مسح الكل</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>إلغاء تثبيت</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>تثبيت</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>إعداد الإشعارات</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>الآن</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 دقيقة مضت</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 ساعة مضت</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>أمس </translation>
    </message>
</context>
</TS>
